@@ -1,6 +1,6 @@
 #!env perl
 use MyCPAN::App::BackPAN::Indexer;
 
-MyCPAN::App::BackPAN::Indexer->run;
+MyCPAN::App::BackPAN::Indexer->run( @ARGV );
 
 exit( 0 );
\ No newline at end of file
